Package: ggpedigree
Title: Visualizing Pedigrees with 'ggplot2' and 'plotly'
Version: 1.2.0
Date/Publication: 2026-05-30 04:30:03 UTC
Authors@R: c(
    person("S. Mason", "Garrison", email= "garrissm@wfu.edu", role = c("aut", "cre", "cph"),
           comment = c(ORCID = "0000-0002-4804-6003"))
  )
Description: Provides plotting functions for visualizing pedigrees and family trees. The package complements a behavior genetics package 'BGmisc' [Garrison et al. (2024) <doi:10.21105/joss.06203>] by rendering pedigrees using the 'ggplot2' framework. Features include support for duplicated individuals, complex mating structures, integration with simulated pedigrees, and layout customization. Due to the impending deprecation of kinship2, version 1.0 incorporates the layout helper functions from kinship2. The pedigree alignment algorithms are adapted from 'kinship2' [Sinnwell et al. (2014) <doi:10.1159/000363105>]. We gratefully acknowledge the original authors: Jason Sinnwell, Terry Therneau, Daniel Schaid, and Elizabeth Atkinson for their foundational work. 
License: GPL (>= 3)
URL: https://github.com/R-Computing-Lab/ggpedigree/,
        https://r-computing-lab.github.io/ggpedigree/
BugReports: https://github.com/R-Computing-Lab/ggpedigree/issues
Depends: R (>= 4.1.0)
Imports: BGmisc (>= 1.4.1), ggplot2, rlang, dplyr, stringr, utils,
        plotly, scales, tidyr
Suggests: selectr (>= 0.5-1), svglite, kinship2, quadprog, ggrepel,
        paletteer, mockery, patchwork, viridis, knitr, tidyverse,
        purrr, data.table, discord, OpenMx, NlsyLinks, rmarkdown,
        tibble, corrplot, showtext, sysfonts, withr, htmlwidgets,
        testthat (>= 3.0.0), vdiffr
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
LazyData: true
Config/Needs/website: rmarkdown
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-30 04:12:43 UTC; smaso
Author: S. Mason Garrison [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0002-4804-6003>)
Maintainer: S. Mason Garrison <garrissm@wfu.edu>
Repository: CRAN
Built: R 4.5.2; ; 2026-05-30 05:08:06 UTC; unix
