# Generated by roxygen2: do not edit by hand

S3method("[",pedigree)
S3method("[",pedigreeList)
S3method(print,pedigree)
S3method(print,pedigreeList)
export(calculateConnections)
export(calculateCoordinates)
export(countOffspring)
export(countSiblings)
export(generateSpouseList)
export(getDefaultPlotConfig)
export(ggPedigree)
export(ggPedigreeInteractive)
export(ggPhenotypeByDegree)
export(ggRelatednessMatrix)
export(ggpedigree)
export(kinship2_plotPedigree)
export(pedigree)
export(plotPedigree)
import(ggplot2)
importFrom(BGmisc,checkParentIDs)
importFrom(BGmisc,ped2fam)
importFrom(BGmisc,ped2maternal)
importFrom(BGmisc,ped2paternal)
importFrom(BGmisc,recodeSex)
importFrom(dplyr,arrange)
importFrom(dplyr,case_when)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,if_all)
importFrom(dplyr,if_else)
importFrom(dplyr,join_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,pull)
importFrom(dplyr,rename)
importFrom(dplyr,rowwise)
importFrom(dplyr,select)
importFrom(dplyr,slice_min)
importFrom(dplyr,starts_with)
importFrom(dplyr,summarize)
importFrom(dplyr,ungroup)
importFrom(rlang,.data)
importFrom(rlang,sym)
importFrom(stats,median)
importFrom(stats,setNames)
importFrom(stats,weighted.mean)
importFrom(utils,modifyList)
